==> jc-1.4.0.tar.gz: javax/swing/ComponentInputMap.h <==
// public class javax.swing.ComponentInputMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ec5882550c1f0cdd javax_swing_ComponentInputMap
// @dep_class 790c4e1b642750d1 javax_swing_InputMap

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_ComponentInputMap_H_
#define _JC_javax_swing_ComponentInputMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_InputMap$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_ComponentInputMap$sub_refs	_jc_javax_swing_ComponentInputMap$sub_refs;
typedef struct _jc_javax_swing_ComponentInputMap$sub_nonrefs	_jc_javax_swing_ComponentInputMap$sub_nonrefs;
typedef struct _jc_javax_swing_ComponentInputMap$refs	_jc_javax_swing_ComponentInputMap$refs;
typedef struct _jc_javax_swing_ComponentInputMap$nonrefs	_jc_javax_swing_ComponentInputMap$nonrefs;
typedef struct _jc_javax_swing_ComponentInputMap$object	_jc_javax_swing_ComponentInputMap$object;

typedef const struct _jc_javax_swing_ComponentInputMap$vmethods	_jc_javax_swing_ComponentInputMap$vmethods;
typedef const struct _jc_javax_swing_ComponentInputMap$vtable	_jc_javax_swing_ComponentInputMap$vtable;
typedef const struct _jc_javax_swing_ComponentInputMap$vtype	_jc_javax_swing_ComponentInputMap$vtype;

// Constructors
extern void _jc_javax_swing_ComponentInputMap$method$_init$f0371e99ef84354a(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods
extern void _jc_javax_swing_ComponentInputMap$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *);
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_ComponentInputMap$method$getComponent$b174a2e555173362(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *);
extern void _jc_javax_swing_ComponentInputMap$method$put$fb8e21724c4a5151(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_Object$object *);
extern void _jc_javax_swing_ComponentInputMap$method$remove$ff07ad26ac47d076(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *);
extern void _jc_javax_swing_ComponentInputMap$method$setParent$4079bbcc37324f34(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_InputMap$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$getComponent$b174a2e555173362;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$put$fb8e21724c4a5151;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$remove$ff07ad26ac47d076;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$setParent$4079bbcc37324f34;

// Virtual methods structure
struct _jc_javax_swing_ComponentInputMap$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *);
	struct _jc_javax_swing_JComponent$object	*(*getComponent$b174a2e555173362)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *);
	void	(*put$fb8e21724c4a5151)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_Object$object *);
	void	(*remove$ff07ad26ac47d076)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *);
	void	(*setParent$4079bbcc37324f34)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_InputMap$object *);
};

// Vtable
struct _jc_javax_swing_ComponentInputMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_ComponentInputMap$vmethods	javax_swing_ComponentInputMap;
};

// Vtype
struct _jc_javax_swing_ComponentInputMap$vtype {
	_jc_type			type;
	_jc_javax_swing_ComponentInputMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ComponentInputMap$sub_refs {
	struct _jc_javax_swing_JComponent$object	*component;
};

// Reference instance fields (object)
struct _jc_javax_swing_ComponentInputMap$refs {
    _jc_javax_swing_ComponentInputMap$sub_refs	javax_swing_ComponentInputMap;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ComponentInputMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ComponentInputMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_ComponentInputMap$sub_nonrefs	javax_swing_ComponentInputMap;
};

// Object instance structure
struct _jc_javax_swing_ComponentInputMap$object {
	_jc_javax_swing_ComponentInputMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ComponentInputMap$vtype	*vtype;
	_jc_javax_swing_ComponentInputMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ComponentInputMap$vtype _jc_javax_swing_ComponentInputMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ComponentInputMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ComponentInputMap$class_object;

#endif	/* _JC_javax_swing_ComponentInputMap_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ComponentInputMap.h <==
// public class javax.swing.ComponentInputMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ec5882550c1f0cdd javax_swing_ComponentInputMap
// @dep_class 790c4e1b642750d1 javax_swing_InputMap

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_ComponentInputMap_H_
#define _JC_javax_swing_ComponentInputMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_InputMap$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_KeyStroke$object;

// Typedefs
typedef struct _jc_javax_swing_ComponentInputMap$sub_refs	_jc_javax_swing_ComponentInputMap$sub_refs;
typedef struct _jc_javax_swing_ComponentInputMap$sub_nonrefs	_jc_javax_swing_ComponentInputMap$sub_nonrefs;
typedef struct _jc_javax_swing_ComponentInputMap$refs	_jc_javax_swing_ComponentInputMap$refs;
typedef struct _jc_javax_swing_ComponentInputMap$nonrefs	_jc_javax_swing_ComponentInputMap$nonrefs;
typedef struct _jc_javax_swing_ComponentInputMap$object	_jc_javax_swing_ComponentInputMap$object;

typedef const struct _jc_javax_swing_ComponentInputMap$vmethods	_jc_javax_swing_ComponentInputMap$vmethods;
typedef const struct _jc_javax_swing_ComponentInputMap$vtable	_jc_javax_swing_ComponentInputMap$vtable;
typedef const struct _jc_javax_swing_ComponentInputMap$vtype	_jc_javax_swing_ComponentInputMap$vtype;

// Constructors
extern void _jc_javax_swing_ComponentInputMap$method$_init$f0371e99ef84354a(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ComponentInputMap$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JComponent$object *_jc_javax_swing_ComponentInputMap$method$getComponent$b174a2e555173362(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ComponentInputMap$method$put$fb8e21724c4a5151(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ComponentInputMap$method$remove$ff07ad26ac47d076(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_ComponentInputMap$method$setParent$4079bbcc37324f34(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_InputMap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$getComponent$b174a2e555173362;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$put$fb8e21724c4a5151;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$remove$ff07ad26ac47d076;
extern _jc_method _jc_javax_swing_ComponentInputMap$method_info$setParent$4079bbcc37324f34;

// Virtual methods structure
struct _jc_javax_swing_ComponentInputMap$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_JComponent$object	*(*getComponent$b174a2e555173362)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *) _JC_JCNI_ATTR;
	void	(*put$fb8e21724c4a5151)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*remove$ff07ad26ac47d076)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_KeyStroke$object *) _JC_JCNI_ATTR;
	void	(*setParent$4079bbcc37324f34)(_jc_env *, struct _jc_javax_swing_ComponentInputMap$object *, struct _jc_javax_swing_InputMap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ComponentInputMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_ComponentInputMap$vmethods	javax_swing_ComponentInputMap;
};

// Vtype
struct _jc_javax_swing_ComponentInputMap$vtype {
	_jc_type			type;
	_jc_javax_swing_ComponentInputMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ComponentInputMap$sub_refs {
	struct _jc_javax_swing_JComponent$object	*component;
};

// Reference instance fields (object)
struct _jc_javax_swing_ComponentInputMap$refs {
    _jc_javax_swing_ComponentInputMap$sub_refs	javax_swing_ComponentInputMap;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ComponentInputMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ComponentInputMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_ComponentInputMap$sub_nonrefs	javax_swing_ComponentInputMap;
};

// Object instance structure
struct _jc_javax_swing_ComponentInputMap$object {
	_jc_javax_swing_ComponentInputMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ComponentInputMap$vtype	*vtype;
	_jc_javax_swing_ComponentInputMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ComponentInputMap$vtype _jc_javax_swing_ComponentInputMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ComponentInputMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ComponentInputMap$class_object;

#endif	/* _JC_javax_swing_ComponentInputMap_H_ */
